@@ -7,6 +7,9 @@ from model_report.report import reports
 
 
 def report_list(request):
+    """
+    This view render all reports registered
+    """
     context = {
         'report_list': reports.get_reports()
     }
@@ -14,10 +17,19 @@ def report_list(request):
 
 
 def report(request, slug):
-    report = reports.get_report(slug)
-    if not report:
+    """
+    This view render one report
+
+    Keywords arguments:
+    
+    slug -- slug of the report
+    """
+    report_class = reports.get_report(slug)
+    if not report_class:
         raise Http404
     context = {
         'report_list': reports.get_reports()
     }
+    
+    report = report_class(request=request)
     return report.render(request, extra_context=context)
